/*
 * JBoss, the OpenSource J2EE webOS
 *
 * Distributable under LGPL license.
 * See terms of license at gnu.org.
 */
package org.jboss.tutorial.stateless.client;

import org.jboss.tutorial.stateless.bean.Calculator;
import org.jboss.tutorial.stateless.bean.CalculatorBean;

import javax.naming.InitialContext;

public class Client
{
   public static void main(String[] args) throws Exception
   {
      // Store a reference to the calculator interface
      Calculator calculator = null;

      // Decide whether to use a POJO or connect to an EJB
      if (args.length != 1)
      {
        System.err.println("Usage: java org.jboss.tutorial.client.Client [-pojo|-ejb]");
        System.exit(1);
      }
      else if (args[0].equals("-pojo"))
      {
        // Simply create a new POJO to act as the calculator
        System.out.println("Creating a new CalculatorBean POJO");
        calculator = new CalculatorBean();
      }
      else if (args[0].equals("-ejb"))
      {
        // Obtain an initial context
        InitialContext ctx = new InitialContext();
        
        // Look up a remote interface to a calculator EJB
        System.out.println("Obtaining a reference to a remote CalculatorBean EJB");
        calculator = (Calculator) ctx.lookup("CalculatorBean/remote");
      }
      else
      {
        System.err.println("Usage: java org.jboss.tutorial.client.Client [-pojo|-ejb]");
        System.exit(1);        
      }

      if (calculator != null)
      {
        System.out.println("[Client] 1 + 1 = " + calculator.add(1, 1));
        System.out.println("[Client] 1 - 1 = " + calculator.subtract(1, 1));
        System.out.println("[Client] 2 + 2 = " + calculator.add(2, 2));
        System.out.println("[Client] 2 * 3 = " + calculator.multiply(2, 3));
      }
   }
}
